pub struct Score {
pub key_type: ScoreKey,
pub key_value: String,
pub points: f64,
}Expand description
Represents a Score
Fields
key_type: ScoreKeyAn enum value that identifies the type of key used to identify the Score object
key_value: StringThe key used to identify the Score object
points: f64The points the key has received as a score of relavence
Implementations
Sourceimpl Score
impl Score
Sourcepub fn new(ktype: ScoreKey, kvalue: String, pnts: f64) -> Score
pub fn new(ktype: ScoreKey, kvalue: String, pnts: f64) -> Score
Constructs a Score object
Arguments
- ktype: ScoreKey- The
ScoreKeyenum value that identifies the type of score key, (e.g.: ScoreKey::KeyWord). - kvalue: String - A key that identifies the score, (e.g.: “dob”).
- pnts: f64 - The scored points that the key has received
#Example
use pbd::dpi::{Score, ScoreKey};
let score = Score::new(ScoreKey::KeyWord,"dob".to_string(),25.0);Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Score
impl<'de> Deserialize<'de> for Score
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more